====================
ilds
====================

**ilds** 是一个常用模块的集合，为了多平台，多电脑调用方便

功能模块包含:

* 获取文件md5
* 处理文件内容

安装：
-------------
pip install -U ilds


简单的例子:
-------------

.. code-block:: python

   import ilds

   from lds.file import is_file
 


更新日志
-------------

0.1.11.1
^^^^^^^^^^
* 添加了 excel_xlsx.get_title_style （excel表头颜色）

0.1.10
^^^^^^^^^^
* 添加了几个时间相关的函数

* form_time_to_year_mon_day
解析数字形式的日期 为 year-mon-day

* date_from_str
从字符串返回日期时间对象，格式为 YYYYMMDD 或（现在|今日）+ - ] [0-9]（天|周|月|年）？（S）

* hyphenate_date
将“YYYYMMDD”格式的日期转换为“YYYY-MM-DD”格式

* DateRange
表示两个日期之间的时间间隔

* srt_subtitles_timecode
秒转换为时间字符串 01:02:03,000

0.1.9
^^^^^^^^^^
* 添加字典排序

0.1.8
^^^^^^^^^^
* excel_xlrd 添加歌曲名和歌手名中标点符号的处理

0.1.7
^^^^^^^^^^
* 将零索引列单元格引用转换为字符串。

0.1.6
^^^^^^^^^^
* django 添加 CLEAN_STR 需要清洗的字符（用在歌曲名，表演者匹配的时候）

0.1.5
^^^^^^^^^^
* 添加命令行交互提示

0.1.4
^^^^^^^^^^
* 添加 django 模型的处理

0.1.3
^^^^^^^^^^
* 修复 excel_xlsx 自动填充 0 的问题
* json 保存格式改成两个空格，减少体积

0.1.2
^^^^^^^^^^
* 添加读取excel文件(openpyxl)
* 支持读取公式

0.1.1
^^^^^^^^^^
* 添加读取excel文件


0.1.0
^^^^^^^^^^
* 导入统一修改为 ilds
* 修改说明文档为 rst 格式

0.0.9
^^^^^^^^^^
* 把安装包加入到官方的pip服务器
* 修改包名字为 ilds 因为 lds 已经被使用
* 导入还是使用 lds

0.0.7
^^^^^^^^^^
* 添加了更多文件处理函数
* 添加了更多时间处理函数
* 添加了获取ip地址的函数

0.0.5
^^^^^^^^^^
* 修正路径问题